@@ -10,6 +10,8 @@ _RAYON = station._RAYON
 _TEMPS_ANIM = 1000
 _TEMPS_CLICK = 750
 
+#FOND = View
+
 class Fond(QGraphicsView):
 
     def __init__(self, parent=None):
@@ -23,16 +25,20 @@ class Fond(QGraphicsView):
         self.moved = False
         self.dblClicked = False
 
-        self.anim = QSequentialAnimationGroup()
-        self.anim.finished.connect(self.anim.clear)
+        self.animSeq = QSequentialAnimationGroup()
+        self.animSeq.finished.connect(self.animSeq.clear)
+        
+        self.animPar = QParallelAnimationGroup()
+        self.animPar.finished.connect(self.animPar.clear)
 
 
+###Events
+
     def resizeEvent ( self, event ):
         self.emit(SIGNAL("resized()"))
 
         
     def mouseDoubleClickEvent(self, event):
-        #self.emit(SIGNAL("doubleClicked"))
         self.dblClicked = True
         self.myFirstPoint = event.pos()
         self.myCurrentPoint = event.pos()
@@ -49,7 +55,6 @@ class Fond(QGraphicsView):
         else:
             self.dblClicked = False
             self.moved = False
-        #self.myFirstScale = self.Scale
         QGraphicsView.mouseReleaseEvent (self, event)
             
 
@@ -59,6 +64,11 @@ class Fond(QGraphicsView):
         self.myCurrentPoint = event.pos()
         QGraphicsView.mouseMoveEvent (self, event)
 
+###Actions
+
+    def decalage(self,i):
+        self.translate(i*2000,200)
+        self.update() 
 
     def dist(self,A,B):
         return math.sqrt((A.x() - B.x())**2 + (A.y() - B.y())**2)
@@ -67,16 +77,19 @@ class Fond(QGraphicsView):
     def zoom(self,point):
         centre = QPointF(0,0)
         scale = self.dist(point,centre) / self.dist(self.myFirstPoint,centre) 
-#        print 'scale:' , scale , scale**.2
+        self.multScale(scale)
+
+    def multScale(self,scale):
         self.Scale = max(min(self.Scale * scale**.5, 5.),.21)
         if self.Scale != 5. and self.Scale != .21:
             self.scale( scale**.5, scale**.5)
-            self.emit(SIGNAL("zoom(float)"),scale**.5)
+#            self.emit(SIGNAL("zoom(float)"),scale**.5)
             self.update()
-        
-    def decalage(self,i):
-        self.translate(i*2000,200)
-        self.update()
+            
+    def getScale(self):
+        return self.Scale
+
+    scaling = pyqtProperty(float, fget=getScale, fset=multScale)
         
     def setCenter(self,point):
         self.centerOn(point)
@@ -85,38 +98,49 @@ class Fond(QGraphicsView):
         return self.mapToScene(self.rect().center())
 
     center = pyqtProperty(QPointF, fget=getCenter, fset=setCenter)
+    
+    def goTo(self,point,scale,sign=1):
+
+        self.animPar.stop()
+        self.animPar.clear()
+    
+        anim = QPropertyAnimation (self, "center")
+        anim.setDuration(_TEMPS_ANIM*2)
+        anim.setEasingCurve(QEasingCurve.OutQuad)
+        anim.setKeyValueAt(0, self.getCenter())
+        anim.setKeyValueAt(1, point)
+        self.animPar.addAnimation(anim)
+        
+        val = (2./scale)**(sign*.05)
+        anim2 = QPropertyAnimation (self, "scaling")
+        anim2.setDuration(_TEMPS_ANIM*2)
+        anim2.setEasingCurve(QEasingCurve.Linear)
+        anim2.setKeyValueAt(0, val)
+        anim2.setKeyValueAt(1, val)
+        self.animPar.addAnimation(anim2)
         
 
-#        
+        
+
+#CARTE  = Scene   
 
 class Carte(QGraphicsScene):
 
     def doubleClick  ( self, p ):
-        #print "pos du click", p
-        #try:
-        #    self.emit(SIGNAL("clicked(QString,QPointF)"), QString(self.itemAt(p).name),p)
-            
-        #except AttributeError:
-        self.emit(SIGNAL("unclicked(QPointF)"),p)
-        #QGraphicsScene.mouseDoubleClickEvent (self, e)
+        self.emit(SIGNAL("dblclicked(QPointF)"),p)
 
 
-        
-        
-   
+      
+      
+#Panneau Station  
 
-        
-
-class PanDepart(QLabel):   
+class PanStation(QLabel):   
     def __init__(self, parent=None):
-        super(PanDepart, self).__init__(parent)
+        super(PanStation, self).__init__(parent)
 
         self.state = False
         self.setFont(QFont ( "Nokia Sans",_RAYON*2  ))
         self.setAlignment(Qt.AlignCenter)
-#        self.setAutoFillBackground(True)
-#        self.palette().setColor(QPalette.Text,Qt.red)
-#        self.palette().setCurrentColorGroup(1)
         self.setStyleSheet("background-color: qlineargradient(x1:-0.5, y1:-0.5, x2:1, y2:1, stop:0 white,  stop:1 palette(highlight)) ; color: palette(highlighted-text) ;border:3px solid gray; border-top-style: none; border-right-style: none")
 
         self.animX = QPropertyAnimation (self, "pos")
@@ -129,9 +153,6 @@ class PanDepart(QLabel):
 
 
     def playX(self,w,text=''):
-        
-        #print 'clicked', rect.x()+200
-
         y = self.y()
         if not self.state and text != '':
             size = self.fontMetrics().size(Qt.TextSingleLine,text)
@@ -158,9 +179,11 @@ class PanDepart(QLabel):
         QLabel.mouseReleaseEvent (self, event)
 
 
-class PanIti(QLabel):   
+#Panneau  Action
+
+class PanAction(QLabel):   
     def __init__(self, parent=None):
-        super(PanIti, self).__init__(parent)
+        super(PanAction, self).__init__(parent)
         
         self.setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing_pending.png"))
         self.setScaledContents( True )
@@ -201,16 +224,14 @@ class PanIti(QLabel):
         if not self.toggle:
             self.emit(SIGNAL("colorise"))
         else:
-            self.emit(SIGNAL("inverse"))
+            self.emit(SIGNAL("play"))
         QLabel.mouseReleaseEvent (self, event)
 
     def playX(self,w,text=''):
         
-        #print 'clicked', rect.x()+200
 
         y = self.y()
         if not self.state and text != '':
-            #size = self.fontMetrics().size(Qt.TextSingleLine,text)
             
             self.text = text
             self.animX.setKeyValueAt(0, QPoint(900,y))
@@ -228,25 +249,29 @@ class PanIti(QLabel):
             self.animX.start()
             self.setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing_pending.png"))
 
+#Boutton Du GPS
 
 class GpsButton(QLabel):   
     def __init__(self, parent=None):
         super(GpsButton, self).__init__(parent)
-        self.pixOn = QPixmap("/usr/share/icons/hicolor/48x48/hildon/location_applet_track_stop_ani.png")
-        self.pixOff = QPixmap("/usr/share/icons/hicolor/48x48/hildon/location_applet_on")
-        self.setPixmap (  self.pixOff)
+        self.pixNo = QPixmap("/usr/share/icons/hicolor/48x48/hildon/location_applet_off.png")
+        self.pixOn = QPixmap("/usr/share/icons/hicolor/48x48/hildon/location_applet_track_start.png")
+        self.pixGood = QPixmap("/usr/share/icons/hicolor/48x48/hildon/location_applet_track_stop_ani.png")
+        self.pixOff = QPixmap("/usr/share/icons/hicolor/48x48/hildon/sketch_circle.png")
+        
+        self.setPixmap (  self.pixNo)
         self.state = False
         
+        
         self.click = QTimer(self)
         self.click.setSingleShot (True )
         
     def center(self):
-        if self.state:
-            self.emit(SIGNAL("gpsCenter"))
+        #if self.state:
+        self.emit(SIGNAL("gpsCenter"))
         self.click.stop()
 
     def mouseDoubleClickEvent(self, event):
-        #self.emit(SIGNAL("doubleClicked"))
         self.changeState()
         QLabel.mouseDoubleClickEvent (self, event)
         
@@ -260,23 +285,35 @@ class GpsButton(QLabel):
         self.click.start(_TEMPS_CLICK)
         QLabel.mousePressEvent (self, event)
         
+    def setPix(self,t):
+        if t == 'On':
+            self.setPixmap (  self.pixOn)
+        elif t == 'Good':
+            self.setPixmap (  self.pixGood)
+        elif t == 'Off':
+            self.setPixmap (  self.pixOff)
+        elif t == 'No':
+            self.setPixmap (  self.pixNo)
+        
 
     def changeState(self):
         self.click.stop()
         if self.state:
             
             self.emit(SIGNAL("gpsOff"))
-            self.setPixmap (  self.pixOff)
-            QObject.disconnect(self.click, SIGNAL("timeout()"), self.center)
+            self.setPix('Off')
+#            QObject.disconnect(self.click, SIGNAL("timeout()"), self.center)
             self.state = False
 
         else:
             self.emit(SIGNAL("gpsOn"))
-            self.setPixmap (  self.pixOn)
+            self.setPix('On')
             QObject.connect(self.click, SIGNAL("timeout()"), self.center)
             self.state = True
 
-        
+
+
+#Point du GPS        
         
 class Gps(QGraphicsEllipseItem):
     def __init__(self, parent=None):
@@ -298,7 +335,6 @@ class Gps(QGraphicsEllipseItem):
         return self.rect().height()
 
     def selec(self):
-        print 'selec gps'
         gradient = QRadialGradient(0,0, _RAYON*1.5)
         gradient.setColorAt(0, Qt.white)
         gradient.setColorAt(1, Qt.red)
@@ -306,7 +342,6 @@ class Gps(QGraphicsEllipseItem):
         
    
     def deselec(self):
-        print 'deselec gps'
         gradient = QRadialGradient(0,0, _RAYON*1.5)
         gradient.setColorAt(1, Qt.black)
         gradient.setColorAt(0, Qt.red)
