@@ -4,6 +4,7 @@
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 from PyQt4.QtXml import *
+from PyQt4.QtMaemo5 import *
 from PyQt4.QtMobility.QtLocation import *
 from PyQt4.QtMobility.QtBearer import *
 
@@ -16,6 +17,8 @@ import dijkstra
 import classes
 import station
 
+import time
+
 _RAYON = station._RAYON
 _TEMPS_ANIM = 1000
 
@@ -23,39 +26,23 @@ graph = station.graph
 
 
   
-def multRayon(x):
-    global _RAYON
-    _RAYON = _RAYON/x
-        
-    
-    
-
             
 
 class Ui_MainWindow(QMainWindow):
 
-#    def event_Filter(self, object, event):
-#        if event.type() == QEvent.MouseButtonDblClick:
-#            object.emit(SIGNAL("doubleClicked()"))
-#            return 1
-#        elif event.type() == QEvent.MouseButtonRelease:
-#            object.emit(SIGNAL("clicked(const QWidget & widget)"), object)
-#            return 1
-#        elif event.type() == QEvent.MouseButtonPress:
-#            object.emit(SIGNAL("clicked(const QWidget & widget)"), object)
-#            return 1
-#        else:
-#            return 0
     m_logfileInUse = False
-    m_location = None
-
-    locationLabel = None
-
-    m_session = 0
-#    m_connectivityHelper = None
 
     m_latitude = -1000
     m_longitude = -1000
+    
+    m_accuracy = False
+
+
+    def closeEvent(self,event):
+        self.m_location.stopUpdates()
+        self.m_session.close()
+#        print 'closing'
+        QMainWindow.closeEvent (self, event)
 
 
     def __init__(self, parent = None):
@@ -74,125 +61,195 @@ class Ui_MainWindow(QMainWindow):
         self.m_location.positionUpdated.connect(self.positionUpdated)
 
         if self.m_logfileInUse:
-            QMessageBox.information(self, self.tr("Flickr Demo"), self.tr("No GPS support detected, using GPS data from a sample log file instead."))
+            QMessageBox.information(self, self.tr("Rtap"), self.tr("No GPS support detected, using GPS data from a sample log file instead."))
     
         manager = QNetworkConfigurationManager()
         canStartIAP = (manager.capabilities() and QNetworkConfigurationManager.CanStartAndStopInterfaces)
         cfg = manager.defaultConfiguration()
         if not cfg.isValid() or (not canStartIAP and cfg.state() != QNetworkConfiguration.Active):
-            QMessageBox.information(self, self.tr("Flickr Demo"), self.tr("Available Access Points not found."))
+            QMessageBox.information(self, self.tr("Rtap"), self.tr("Available Access Points not found."))
             return
-    
-        self.m_session = QNetworkSession(cfg, self)
-#        self.m_connectivityHelper = ConnectivityHelper(self.m_session, self)
-        self.m_session.opened.connect(self.networkSessionOpened)
-#        self.connect(self.m_connectivityHelper, SIGNAL('networkingCancelled()'), qApp, SLOT('quit()'))
-    
-#        self.m_session.open()
 
-    
+        self.m_session = QNetworkSession(cfg, self)
+        self.m_session.opened.connect(self.networkSessionOpened)
+
+    # Start listening GPS position updates    
     def networkSessionOpened(self):
-        # Start listening GPS position updates
+#        print 'a'
         self.m_location.startUpdates()
+#        print 'b'
 
     def positionUpdated(self, gpsPos):
         if gpsPos.isValid():
             coord = gpsPos.coordinate()
             self.m_latitude = coord.latitude()
             self.m_longitude = coord.longitude()
-#            print self.m_latitude , self.m_longitude
             self.gps.setPos( (self.m_longitude*10-20)*500,-(self.m_latitude*10-488)*700)
             graph["GPS"].setPos(self.m_longitude, self.m_latitude)
-
-    def openSession(self):
-        self.m_session.open()
+            if gpsPos.attribute(QGeoPositionInfo.HorizontalAccuracy) < 80 or gpsPos.attribute(QGeoPositionInfo.VerticalAccuracy) < 80:
+                self.gpsButton.setPix('Good')
+            else:
+                self.gpsButton.setPix('On')
+    
+    def addGPS(self):
         self.scene.addItem(self.gps)
+        QObject.disconnect(self.gpsButton, SIGNAL("gpsOn"), self.addGPS)
         
     def closeSession(self):
-        QTimer.singleShot(0, self.m_location.stopUpdates)
+        self.m_location.stopUpdates()
+#        QTimer.singleShot(0, self.m_location.stopUpdates)
         QTimer.singleShot(0, self.m_session.close)
 #        self.scene.removeItem(self.gps) 
 
     def gpsCenter(self):
 
-#        self.view.goTo(QPointF(self.gps.x(),self.gps.y()))
-
-        anim = QPropertyAnimation (self.view, "center")
-        anim.setDuration(_TEMPS_ANIM)
-        anim.setEasingCurve(QEasingCurve.OutBack)
-        anim.setKeyValueAt(0, self.view.getCenter())
-        anim.setKeyValueAt(1, QPointF(self.gps.x(),self.gps.y()))
-        self.view.anim.addAnimation(anim)
-        
-        self.view.anim.start()
-        
-#    def viewCenter(self,point,curve = QEasingCurve.OutBack):
-#        self.view.anim.setDuration(_TEMPS_ANIM)
-#        self.view.anim.setEasingCurve(curve)
-#        self.view.anim.setKeyValueAt(0, self.view.getCenter())
-#        self.view.anim.setKeyValueAt(1, point)
-#        self.view.anim.start()
+        self.view.goTo(QPointF(self.gps.x(),self.gps.y()),self.view.getScale())
+        self.view.animPar.start()
         
     def play(self):
+
         n = len(self.Chemin) - 1
         i = 1
         if n == 0:
             return
         else:
-            QObject.disconnect(self.panIti, SIGNAL("inverse"), self.play)
-            self.panIti.setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/camera_video_stop.png"))
-            self.view.anim.stop()
-            self.view.anim.clear()
-    
+            self.panAction.setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/camera_video_stop.png"))
+            self.view.animSeq.stop()
+            self.view.animSeq.clear()
+            
+            #Anim Center
+
             animCenter = QPropertyAnimation (self.view, "center")
-            animCenter.setDuration(_TEMPS_ANIM)
+            animCenter.setDuration(_TEMPS_ANIM*2)
             animCenter.setEasingCurve(QEasingCurve.OutQuad)
             animCenter.setKeyValueAt(0, self.view.getCenter())
             animCenter.setKeyValueAt(1, QPointF(  graph[self.Chemin[0]].posX,  graph[self.Chemin[0]].posY ))
-            self.view.anim.addAnimation(animCenter)
+
+
+            #Anime Zoom    
             
-            self.view.anim.addPause(_TEMPS_ANIM/2)
-    
-    
-#            self.viewCenter(QPointF(  graph[self.Chemin[0]].posX,  graph[self.Chemin[0]].posY ))
-            scale = 5./ self.view.Scale
-            self.view.scale( scale, scale)
-            self.view.Scale = 5.
-            self.view.update()
+            val = (5./self.view.getScale())**(.2)
+            animZoom = QPropertyAnimation (self.view, "scaling")
+            animZoom.setDuration(_TEMPS_ANIM*2)
+            animZoom.setEasingCurve(QEasingCurve.Linear)
+            animZoom.setKeyValueAt(0, val)
+            animZoom.setKeyValueAt(1, val)
 
+            animParIn = QParallelAnimationGroup()
+            animParIn.addAnimation(animCenter)
+            animParIn.addAnimation(animZoom)
 
+            #Start anim
+            self.view.animSeq.addAnimation(animParIn)
+            self.view.animSeq.addPause(_TEMPS_ANIM/2)
+
+            #Follow stations
             while i < n+1:
                 anim = QPropertyAnimation (self.view, "center")
                 anim.setDuration(_TEMPS_ANIM)
                 anim.setEasingCurve(QEasingCurve.InOutCubic)
                 anim.setKeyValueAt(0, QPointF(  graph[self.Chemin[i-1]].posX,  graph[self.Chemin[i-1]].posY )  )
                 anim.setKeyValueAt(1, QPointF(  graph[self.Chemin[i]].posX,  graph[self.Chemin[i]].posY )  )
-                self.view.anim.addAnimation(anim)
+                self.view.animSeq.addAnimation(anim)
                 i += 1
     
 
+            #Anim UnCenter 
+
+            animUnCenter = QPropertyAnimation (self.view, "center")
+            animUnCenter.setDuration(_TEMPS_ANIM*2)
+            animUnCenter.setEasingCurve(QEasingCurve.OutQuad)
+            animUnCenter.setKeyValueAt(0, QPointF(  graph[self.Chemin[-1]].posX,  graph[self.Chemin[-1]].posY ))
+            
+            dx = abs(graph[self.Chemin[-1]].posX - graph[self.Chemin[0]].posX)
+            dy = abs(graph[self.Chemin[-1]].posY - graph[self.Chemin[0]].posY)
+            if graph[self.Chemin[-1]].posX - graph[self.Chemin[0]].posX > 0:
+                x = graph[self.Chemin[0]].posX + dx/2
+            else:
+                x = graph[self.Chemin[0]].posX - dx/2
+
+            if graph[self.Chemin[-1]].posY - graph[self.Chemin[0]].posY > 0:
+                y = graph[self.Chemin[0]].posY + dy/2
+            else:
+                y = graph[self.Chemin[0]].posY - dy/2 
+            animUnCenter.setKeyValueAt(1, QPointF(  x,  y ))
+
+            #Anime UnZoom    
+            
+            w = self.width()
+            h = self.height()
+            Sx = (w/(dx+10))
+            Sy = (h/(dy+10))
+            S = max(min(Sx,Sy,5.0),.21)
+#            print w, h, dx
+
+            val = ((S) /5.)**(.2)
+            
+            animUnZoom = QPropertyAnimation (self.view, "scaling")
+            animUnZoom.setDuration(_TEMPS_ANIM*2)
+            animUnZoom.setEasingCurve(QEasingCurve.Linear)
+            animUnZoom.setKeyValueAt(0, val)
+            animUnZoom.setKeyValueAt(1, val)
+
+            animParOut = QParallelAnimationGroup()
+            animParOut.addAnimation(animUnCenter)
+            animParOut.addAnimation(animUnZoom)
+
+            self.view.animSeq.addPause(_TEMPS_ANIM/2)
+            self.view.animSeq.addAnimation(animParOut)
 
 
-            self.view.anim.finished.connect(self.stop)
-#            QObject.connect(self.panIti, SIGNAL("inverse"), self.view.anim.stop)
-            QObject.connect(self.panIti, SIGNAL("inverse"), self.stop)
-            self.view.anim.start()
+
+            QObject.disconnect(self.panAction, SIGNAL("play"), self.play)
+            QObject.connect(self.panAction, SIGNAL("play"), self.stop)
+            self.view.animSeq.finished.connect(self.stop)
+            self.view.animSeq.start()
 
     def stop(self):
-        self.view.anim.stop()
-        self.panIti.setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/camera_playback.png"))
-        QObject.disconnect(self.panIti, SIGNAL("inverse"), self.view.anim.stop)
-        QObject.connect(self.panIti, SIGNAL("inverse"), self.play)
+        if self.view.animSeq.state() != QAbstractAnimation.Stopped:
+            self.view.animSeq.stop()
+        
+        self.panAction.setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/camera_playback.png"))
+        QObject.disconnect(self.panAction, SIGNAL("play"), self.view.animSeq.stop)
+        QObject.connect(self.panAction, SIGNAL("play"), self.play)
 
+        
+    def search(self):
+        value , ok = QInputDialog.getText( self.view, "Rtap : Recherche", "Saisissez les termes de votre recherche.", )
+        result = []
+        if ok:
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+            for element in graph:
+                if str(value) in element:
+                    result += [element]
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+            if len(result) == 0:
+                QMaemo5InformationBox.information( self, 'La recherche n\'a donn\xe9 aucun r\xe9sultat.' )
+            elif len(result) == 1:
+                self.setSelec(result[0])
+                
+                self.view.goTo(graph[result[0]].Pos(),self.view.getScale())
+                self.view.animPar.start()
+            elif len(result) > 1:
+                Selec , ok = QInputDialog.getItem ( self.view, "Rtap : Recherche", "Liste des r\xe9sultats. Choisissez une station :", result, 0, False)
+                if ok:
+                    self.setSelec(Selec)
+                    self.view.goTo(graph[str(Selec)].Pos(),self.view.getScale())
+                    self.view.animPar.start()
+    
+                    if Selec == 'GPS':
+                        self.gps.selec()
+                        self.gpsCenter()
+                    
+                
 
     def setSelec(self,Name):
         
         Nom = str(Name)
-        print self.view.mapFromScene(graph[Nom].pos())
         
         w = self.width()
         h = self.height()
-        if self.panIti.toggle:
+        if self.panAction.toggle:
             if self.Selec[0] != Nom and Nom != self.Selec[1]:
                 for value in graph:
                     graph[value].deselec()
@@ -202,7 +259,7 @@ class Ui_MainWindow(QMainWindow):
                 self.scene.removeItem(self.rectCalc)
                 self.panDepart.playX(w)
                 self.panArrivee.playX(w)
-                self.panIti.playX(w)
+                self.panAction.playX(w)
             
                 self.Selec = (Nom,'')
             
@@ -221,7 +278,7 @@ class Ui_MainWindow(QMainWindow):
 
                 self.panDepart.playX(w,Nom)
                 if self.Selec[1] != '':
-                    self.panIti.playX(w,Nom)
+                    self.panAction.playX(w,Nom)
             
         
             else:
@@ -233,76 +290,19 @@ class Ui_MainWindow(QMainWindow):
                     self.scene.update()
                 
                     self.panArrivee.playX(w,Nom)
-                    self.panIti.playX(w,Nom)
-
-            """else:
-            if Nom == self.Selec[0] or Nom == self.Selec[1]:
-                if not self.panIti.toggle:
-                    self.colorise()
-
-            else:
-                if self.panIti.toggle: 
-                    for value in graph:
-                            graph[value].deselec()
-                    self.panDepart.playX(800)
-                    self.panArrivee.playX(800)
-                    self.panIti.playX(800)
-                    self.Selec = (Nom,'')
-                    self.panDepart.playX(800,Nom)
-                    graph[Nom].selec() 
-                    self.scene.update()
-                else:
-                    for value in graph:
-                            graph[value].deselec()
-                    self.panArrivee.playX(800)
-                    self.Selec = (self.Selec[0],Nom)
-                    graph[self.Selec[0]].selec()
-                    graph[Nom].selec()
-                    self.scene.update()
-            
-                    self.panArrivee.playX(800,Nom)
-                
-        if not '' in self.Selec and not self.panIti.toggle:
-            self.panIti.playX(800,Nom)"""
-        
-            #MainWindow.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
-
-
-            #MainWindow.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)'''
-            
-    """def deSelec(self):
-        if not self.panIti.toggle:
-            for value in graph:
-                    graph[value].deselec()
-                    #self.scene.update()
-            self.Selec = ('','')
-            self.panDepart.playX(800)
-            self.panArrivee.playX(800)
-            self.panIti.playX(800)
-        self.scene.update()"""
+                    self.panAction.playX(w,Nom)
         
     def rectSelec(self,p):
         point = self.view.mapFromScene(p)
-        #print p, point
-        r = QRect(point.x()-10.,point.y()-10.,20.,20.)
-        rect = self.view.mapToScene(r)
-        #print "point vide", point, "carre de selec", rect
+        rect = self.view.mapToScene(QRect(point.x()-10.,point.y()-10.,20.,20.))
         liste = self.scene.items(rect)
-        #print liste
         listeNom = []
         for element in liste:
             if element.type() == 65536:
                 listeNom += [element.name]
             elif element.type() == 4:
                 listeNom += ['GPS']
-                
-        #print listeNom
-#        if "GPS" in listeNom:
-#            if listeNom == ["GPS"]:
-#                print 'gps tout seul'
-#                #self.gpsSearch(point)
-#            elif len(listeNom) > 1:
-#                listeNom.remove("GPS")
+
         
         if len(listeNom) == 1:
             self.setSelec(listeNom[0])
@@ -316,22 +316,18 @@ class Ui_MainWindow(QMainWindow):
                     self.gps.selec()
                 
 
-    def gpsSearch(self,x,y):
-        point = self.view.mapFromScene(x,y)
+    def gpsSearch(self,p):
+        point = self.view.mapFromScene(p)
         proche = []
         k = 1
         while proche == []:
             r = QRect(point.x()-k*10.,point.y()-k*10.,k*20.,k*20.)
             rect = self.view.mapToScene(r)
             liste = self.scene.items(rect)
-#            print "proche avant", proche
             for element in liste:
                 if element.type() == 65536 and element.name != "GPS":
                     proche += [element]
-                    print element.name
-#            print 'apres', proche
             k += 1
-        print k
         listeNom = []
         for element in proche:
             if element.type() == 65536:
@@ -360,35 +356,36 @@ class Ui_MainWindow(QMainWindow):
             if self.Selec[1] != '':
                 graph[self.Selec[1]].selec()
             self.panDepart.playX(w)
-            self.panIti.playX(w)
+            self.panAction.playX(w)
         else:
             self.Selec = (self.Selec[0],'')
             if self.Selec[0] != '':
                 graph[self.Selec[0]].selec()
             self.panArrivee.playX(w)
-            self.panIti.playX(w)
+            self.panAction.playX(w)
         if Nom == 'GPS':
             self.gps.deselec()
         
         
         
     def colorise(self):
+        t0= time.time()
         self.scene.addItem(self.rectCalc)
         self.CheminItem = []
-        print self.Selec
         if self.Selec[0] == 'GPS':
-            proche = self.gpsSearch(self.gps.x(),self.gps.y())
+            proche = self.gpsSearch(self.gps.pos())
             graph['GPS'].addCorres(str(proche))
-            self.Chemin = ['GPS'] + dijkstra.algo(str(proche),self.Selec[1])
+            self.Chemin , tps = dijkstra.algo(str(proche),self.Selec[1])
+            self.Chemin = ['GPS'] + self.Chemin
         elif  self.Selec[1] == 'GPS':
-            proche = self.gpsSearch(self.gps.x(),self.gps.y())
-            self.Chemin = dijkstra.algo(self.Selec[0],str(proche)) + ["GPS"]
+            proche = self.gpsSearch(self.gps.pos())
+            self.Chemin ,tps = dijkstra.algo(self.Selec[0],str(proche)) 
+            self.Chemin += ["GPS"]
             graph[str(proche)].addCorres("GPS")
         else:
-            self.Chemin = dijkstra.algo(self.Selec[0],self.Selec[1])
-        #print 'la liste a colorie ', liste
-        #graph[self.Chemin[0]].changeColor(self.palette().midlight().color())
-        #graph[self.Chemin[-1]].changeColor(self.palette().light().color())
+            self.Chemin, tps = dijkstra.algo(self.Selec[0],self.Selec[1])
+
+#        print 'tps de calcul', time.time() - t0
 
         dep = self.Chemin[0]
         for dest in self.Chemin[1:]:
@@ -399,7 +396,7 @@ class Ui_MainWindow(QMainWindow):
                     graph[dest].posX + _RAYON/2, 
                     graph[dest].posY + _RAYON/2, 
                     )
-            line.setPen(QPen(graph[dep].corresColor[idx], _RAYON))
+            line.setPen(QPen(graph[dep].corresColor[idx], _RAYON/2))
             self.CheminItem.append(line)
             dep = dest
         dep = self.Chemin[0]
@@ -417,13 +414,9 @@ class Ui_MainWindow(QMainWindow):
                 gradient.setColorAt(0, graph[dest].color.color())
                 gradient.setColorAt(1, graph[dest].color.color())
                 
-            ellipse = QGraphicsEllipseItem ( 
-                    graph[dest].posX-_RAYON/2, 
-                    graph[dest].posY-_RAYON/2, 
-                    _RAYON*2, 
-                    _RAYON*2, 
-                    )
-            ellipse.setPen(QPen(Qt.NoPen))
+            ellipse = QGraphicsEllipseItem (graph[dest].posX, graph[dest].posY, _RAYON, _RAYON)
+
+            ellipse.setPen(QPen( gradient, _RAYON/2))
             ellipse.setBrush(QBrush(gradient))
             self.CheminItem.append(ellipse)
             dep = dest
@@ -461,31 +454,17 @@ class Ui_MainWindow(QMainWindow):
         for item in self.CheminItem:
             self.scene.addItem(item)
         self.scene.update()
-        self.panIti.toggling()
+        self.panAction.toggling()
         try:
             graph[str(proche)].removeCorres("GPS")
         except UnboundLocalError:
-            print "no GPS"
-        
-    def inverse(self):
-        w = self.width()
-        self.panDepart.playX(w)
-        self.panArrivee.playX(w)
-        self.panIti.playX(w)
-
-        for value in graph:
-            graph[value].deselec()
-        old = self.Selec
-        self.Selec = ('','')
-        
-        self.setSelec(old[1])
-        self.setSelec(old[0])
+            return
         
         
 
     def orientationChanged(self, i):
         self.panArrivee.move(self.panArrivee.x(),app.desktop().screenGeometry().height()-126)
-        self.panIti.move(self.panIti.x(),app.desktop().screenGeometry().height()/2-76)
+        self.panAction.move(self.panAction.x(),app.desktop().screenGeometry().height()/2-76)
         self.view.translate(-150,200)
         
         self.gpsButton.move(16,app.desktop().screenGeometry().height()-80-56)
@@ -494,31 +473,34 @@ class Ui_MainWindow(QMainWindow):
             self.panDepart.move(app.desktop().screenGeometry().width()-min(290,self.panDepart.width()),self.panDepart.y())
         if self.panArrivee.state :
             self.panArrivee.move(app.desktop().screenGeometry().width()-min(290,self.panArrivee.width()),self.panArrivee.y())
-        if self.panIti.state :
-            self.panIti.move(app.desktop().screenGeometry().width()-100,self.panIti.y())
-            self.panIti.animMargin.start()
-
+        if self.panAction.state :
+            self.panAction.move(app.desktop().screenGeometry().width()-100,self.panAction.y())
+            self.panAction.animMargin.start()
 
 
         
     def setupUi(self, App):
         self.setWindowTitle("Rtap")
         self.resize(800,480)
-#        MainWindow.setAttribute(Qt.WA_TranslucentBackground,True)
-#        MainWindow.eventFilter = self.event_Filter
         global app
         app = App
-#        MainWindow = MainWin
+
         self.centralWidget = QWidget(self)
         self.Selec = ('','')
         self.CheminItem = []
         self.Chemin = []
+
+        menubar = QMenuBar(self)
+        self.setMenuBar(menubar)
+        
+        menuChercher = QAction("Recherche",self)
+        menubar.addAction(menuChercher)
+        QObject.connect(menuChercher, SIGNAL("triggered()"), self.search)
         
         self.scene = classes.Carte(self)
         self.scene.setSceneRect(-815.90800894434585, -2585.2493331816809, 5397.5130039461728, 3900.3854289115216)
-        #path = QPainterPath()
-        #path.addEllipse ( 0, 0, _RAYON*2 , _RAYON * 2 )
-        #self.scene.setSelectionArea ( path)
+        
+        #Fleuve
         fleuve = QPainterPath()
         fleuve.moveTo(station.SeineX[0], station.SeineY[0])
         l = len(station.SeineX)
@@ -550,6 +532,7 @@ class Ui_MainWindow(QMainWindow):
            
         self.scene.addPath(fleuve, QPen( QColor(165,191,221), _RAYON*.8))
         
+        #Segment entre stations
         for dep in graph:
             k = 0
             while k < len(graph[dep].corres):
@@ -571,13 +554,13 @@ class Ui_MainWindow(QMainWindow):
                 except IndexError:
                     k += 1
 
+        #Stations
         for value in graph:
             if graph[value].name[-1] != "]" and graph[value].name != 'GPS':
                 self.scene.addItem(graph[value])
-            #graph[value].setFlag(QGraphicsItem.ItemIsSelectable,True)
 
-        #QObject.connect(self.scene, SIGNAL("clicked(QString,QPointF)"), self.setSelec)
-        QObject.connect(self.scene, SIGNAL("unclicked(QPointF)"), self.rectSelec)
+
+        QObject.connect(self.scene, SIGNAL("dblclicked(QPointF)"), self.rectSelec)
 
 
         self.scene.setBackgroundBrush(self.palette().shadow().color())
@@ -589,42 +572,37 @@ class Ui_MainWindow(QMainWindow):
         self.rectCalc = QGraphicsRectItem (self.view.sceneRect())
         self.rectCalc.setBrush(QBrush(QColor(0,0,0,153)))
 
-        self.panDepart = classes.PanDepart(self.view)
+        self.panDepart = classes.PanStation(self.view)
         self.panDepart.setGeometry(900,0,250,180)
         QObject.connect(self.panDepart, SIGNAL("released(QString)"), self.deselec)
         self.panDepart.show()
 
 
-        self.panArrivee = classes.PanDepart(self.view)
+        self.panArrivee = classes.PanStation(self.view)
         self.panArrivee.setGeometry(900,app.desktop().screenGeometry().height()-126,250,180)
         QObject.connect(self.panArrivee, SIGNAL("released(QString)"), self.deselec)
         self.panArrivee.show()
 
-        self.panIti = classes.PanIti(self.view)
-        self.panIti.setGeometry(900,app.desktop().screenGeometry().height()/2-56-20,80,80)
-        QObject.connect(self.panIti, SIGNAL("colorise"), self.colorise)
-        QObject.connect(self.panIti, SIGNAL("inverse"), self.play)
-        self.panIti.show()
-        self.panIti.animMargin.start()
+        self.panAction = classes.PanAction(self.view)
+        self.panAction.setGeometry(900,app.desktop().screenGeometry().height()/2-56-20,80,80)
+        QObject.connect(self.panAction, SIGNAL("colorise"), self.colorise)
+        QObject.connect(self.panAction, SIGNAL("play"), self.play)
+        self.panAction.show()
+        self.panAction.animMargin.start()
 
-##########
-#        self.locationLabel = QLabel(self.tr("Lat: Long:"),self.view)
-#        self.locationLabel.setGeometry(0,0,400,50)
-#        self.locationLabel.show()
+########## GPS
 
         self.gpsButton = classes.GpsButton(self.view)
-        QObject.connect(self.gpsButton, SIGNAL("gpsOn"), self.openSession)
+        QObject.connect(self.gpsButton, SIGNAL("gpsOn"), self.m_session.open)
+        QObject.connect(self.gpsButton, SIGNAL("gpsOn"), self.addGPS)
         QObject.connect(self.gpsButton, SIGNAL("gpsOff"), self.closeSession)
         QObject.connect(self.gpsButton, SIGNAL("gpsCenter"), self.gpsCenter)
         self.gpsButton.setGeometry(16,app.desktop().screenGeometry().height()-80-56,80,80)
         self.gpsButton.show()
 
-
 #        self.gps = graph["GPS"]
         self.gps = classes.Gps()
 
-
-
 #########
 
         if app.desktop().screenGeometry().width() < app.desktop().screenGeometry().height():
@@ -632,6 +610,7 @@ class Ui_MainWindow(QMainWindow):
         else:
             self.view.centerOn(1750.,-400)
         self.view.show()
+        self.view.update()
 
         self.setCentralWidget(self.view)
 
