@@ -20,12 +20,14 @@ class Station(QGraphicsItem):
         self.color = QBrush(color)
         self.pen = QPen(Qt.NoPen)
         self.penIni = self.pen
-        #self.point = QGraphicsEllipseItem ( x*20, y*20, 10., 10. )
         
     def setPos(self,x,y):
         self.posY = -(y*10-488)*700
         self.posX = (x*10-20)*500
         
+    def Pos(self):
+        return QPointF(self.posX,self.posY)
+        
         
     def setColor(self,color):
         self.color = color
@@ -56,10 +58,7 @@ class Station(QGraphicsItem):
 
     def selec(self):
         gradient = QRadialGradient(self.posX,self.posY, _RAYON*1.5)
-        #gradient.setSpread(QGradient.ReflectSpread)
-
         gradient.setColorAt(0, self.color.color().lighter(200))
-#        gradient.setColorAt(0.25, self.color.color())
         gradient.setColorAt(1, self.color.color())
         self.pen = QPen( gradient, _RAYON)
         
@@ -113,7 +112,10 @@ RERB = QColor(83,124,185)
 RERC = QColor(232,206,15)
 RERD = QColor(23,250,76)
 RERE = QColor(199,95,173)
-_RAYON = 12.
+_RAYON = 10.
+
+###Exemple Simple de Graphe
+
 
 #graph = { 'A' : Station('A', ['B','C','Z'] , 1, 5, LigneM, [Ligne2,Ligne4,Ligne2]) , 
 #          'B' : Station('B', ['A','G'] , 2, 3, Ligne2, [Ligne2,Ligne2]) , 
@@ -144,6 +146,9 @@ _RAYON = 12.
 #          }
 #         
 
+
+##############Fleuves
+
 SeineX = [2420.99, 1941.195, 2008.57, 2223.15, 2185.385, 2121.44, 2059.64, 2108.995, 2048.485, 2035.18, 1951.065, 1911.585, 1874.675, 1839.055, 1804.725, 1766.53, 1734.345, 1703.875, 1687.565, 1649.585, 1589.72, 1508.18, 1459.47, 1438.01, 1377.5, 1301.755, 1243.82, 1204.125, 1135.89, 1117.435, 1121.08, 1158.42, 1215.28, 1283.515, 1326.22, 1436.08, 1601.735, 1643.575, 1707.735, 1678.765, 1535.215, 1454.75, 1302.83, 1070.44, 943.415, 873.03, 779.045, 685.92, 549.02, 598.805, 867.025, 836.985, 353.755, 237.885, 134.45, 92.83, 14.725, -11.025, -357.78, -808.389 ]
 
 SeineY = [1306.655, 856.093, 668.101, 488.537, 384.72, 332.423, 236.18, 85.33, -33.404, -123.6129, -178.997, -222.11, -266.399, -304.759, -341.131, -358.925, -372.764, -394.898, -408.338, -420.392, -446.2849, -444.108, -419.209, -389.361, -326.109, -218.743, -171.878, -157.045, -199.759, -289.338, -374.143, -483.042, -544.096, -624.694, -671.1109, -725.018, -812.882, -831.243, -950.453, -1011.626, -1058.582, -1056.209, -1002.743, -814.856, -741.412, -720.475, -558.1239, -499.919, -616.196, -823.935, -1074.164, -1278.872, -1298.584, -1121.897, -1035.888, -912.758, -1172.388, -1284.388, -1436.554, -1295.427 ] 
@@ -160,6 +165,7 @@ MarneX = [2041.185, 2257.05, 2340.305, 2377.215, 2475.49, 2551.02, 2607.67, 2611
 
 MarneY = [-120.848, -110.166, -30.632, 88.8930, 110.271, 113.435, 67.515, -26.6769, -71.3930, -94.3389, -140.623, -190.071, -220.129, -203.9169, -238.721, -273.5179, -332.437, -359.716, -388.9689, -438.382, -466.438, -417.431, -403.991, -522.165, -560.490, -586.572, -646.618, -712.579, -730.744, -724.822, -714.952, -721.2659, -750.491, -852.362, -867.3629, -842.492, -915.523, -962.493, -1022.476, -1038.261, -1026.025, -801.038, -767.865, -744.569, -720.0829, -698.362, -707.049, -754.838, -866.971, -1039.045, -1091.125, -1099.805, -998.011, -945.917, -971.173]
 
+##############Ligne
 
 graph = { 
 'GPS' : Station('GPS', [] , 48.858743,2.347383 , Qt.red , [] ) ,
